<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi">
<context>
    <name>Batchprocessing</name>
    <message>
        <location filename="../src/batchprocessing.cpp" line="44"/>
        <source>Error</source>
        <translation>त्रुटि</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="45"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>वर्तमान कर्नेल हेतु चयनित संपीड़न एल्गोरिथम असमर्थित है, कृपया विन्यास फाइल संपादित कर विभिन्न एल्गोरिथम चुनें।</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="70"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation>प्रोग्राम द्वारा निर्माण अब स्थगित होगा व आपके टेक्स्ट संपादक में बूट मेन्यू खुलेगी।</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="100"/>
        <source>This computer uses an NVIDIA graphics card. Are you planning to use the resulting ISO on the same computer or another computer with an NVIDIA card?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="110"/>
        <source>Note: If you use the resulting ISO on a computer without an NVIDIA card, you will likely need to remove &apos;xorg=nvidia&apos; from the boot options.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="113"/>
        <source>Note: If you use the resulting ISO on a computer with an NVIDIA card, you may need to add &apos;xorg=nvidia&apos; to the boot options.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/ui_mainwindow.h" line="721"/>
        <location filename="../src/mainwindow.cpp" line="182"/>
        <location filename="../src/mainwindow.cpp" line="516"/>
        <source>MX Snapshot</source>
        <translation>एमएक्स स्नैपशॉट</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="33"/>
        <location filename="../src/ui_mainwindow.h" line="722"/>
        <source>Optional customization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="65"/>
        <location filename="../src/ui_mainwindow.h" line="723"/>
        <source>Release version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="79"/>
        <location filename="../src/ui_mainwindow.h" line="724"/>
        <source>Boot options:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="86"/>
        <location filename="../src/ui_mainwindow.h" line="725"/>
        <source>Live kernel:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="93"/>
        <location filename="../src/ui_mainwindow.h" line="726"/>
        <source>Project name:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="100"/>
        <location filename="../src/ui_mainwindow.h" line="727"/>
        <source>Release date:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="107"/>
        <location filename="../src/ui_mainwindow.h" line="728"/>
        <source>Release codename:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="133"/>
        <location filename="../src/ui_mainwindow.h" line="729"/>
        <source>Current date</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="172"/>
        <location filename="../src/ui_mainwindow.h" line="730"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;स्नैपशॉट एक साधन जिसके द्वारा आप संचय व वितरण हेतु अपने कार्यरत सिस्टम की बूट योग्य फाइल (आईएसओ) निर्मित कर सकते हैं। प्रक्रिया के दौरान आप सिस्टम पर सरल अनुप्रयोग उपयोग करना जारी रख सकते हैं।&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="182"/>
        <location filename="../src/ui_mainwindow.h" line="731"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>/ (रुट) व /home विभाजनों पर प्रयुक्त स्पेस :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="192"/>
        <location filename="../src/ui_mainwindow.h" line="732"/>
        <source>Location and ISO name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="219"/>
        <location filename="../src/ui_mainwindow.h" line="734"/>
        <source>Snapshot location:</source>
        <translation>स्नैपशॉट फोल्डर :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="226"/>
        <location filename="../src/ui_mainwindow.h" line="735"/>
        <source>Select a different snapshot directory</source>
        <translation>विभिन्न स्नैपशॉट डायरेक्टरी चुनें</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="236"/>
        <location filename="../src/ui_mainwindow.h" line="736"/>
        <location filename="../src/mainwindow.cpp" line="371"/>
        <source>Snapshot name:</source>
        <translation>स्नैपशॉट नाम :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="360"/>
        <location filename="../src/ui_mainwindow.h" line="740"/>
        <source>Type of snapshot:</source>
        <translation>स्नैपशॉट प्रकार :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="367"/>
        <location filename="../src/ui_mainwindow.h" line="741"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>अकाउंट संरक्षण (व्यक्तिगत बैकअप हेतु)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="377"/>
        <location filename="../src/ui_mainwindow.h" line="743"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;इस विकल्प से &amp;quot;डेमो&amp;quot; व &amp;quot;रूट&amp;quot; कूटशब्द एमएक्स लिनक्स डिफ़ॉल्ट पर सेट होंगे व बनाया गया कोई भी व्यक्तिगत अकाउंट कॉपी नहीं होगा।&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="380"/>
        <location filename="../src/ui_mainwindow.h" line="745"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>अकाउंट पुनः सेट करना जारी (अन्य को वितरण हेतु)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="451"/>
        <location filename="../src/ui_mainwindow.h" line="746"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation>इच्छित डायरेक्टरी अपवर्जन हेतु नीचे दी गई सूची से उन्हें चिन्हित करें या बटन पर क्लिक द्वारा /etc/mx-snapshot-exclude.list संपादित करें।</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="496"/>
        <location filename="../src/ui_mainwindow.h" line="747"/>
        <source>sha512</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="519"/>
        <location filename="../src/ui_mainwindow.h" line="749"/>
        <source>Throttle the I/O input rate by the given percentage.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="525"/>
        <location filename="../src/ui_mainwindow.h" line="751"/>
        <source>I/O throttle:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="532"/>
        <location filename="../src/ui_mainwindow.h" line="752"/>
        <source>Calculate checksums:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="539"/>
        <location filename="../src/ui_mainwindow.h" line="753"/>
        <source>ISO compression scheme:</source>
        <translation>आईएसओ संपीड़न विधि :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="546"/>
        <location filename="../src/ui_mainwindow.h" line="754"/>
        <source>Number of CPU cores to use:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="553"/>
        <location filename="../src/ui_mainwindow.h" line="755"/>
        <source>md5</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="563"/>
        <location filename="../src/ui_mainwindow.h" line="756"/>
        <source>Options:</source>
        <translation>विकल्प :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="608"/>
        <location filename="../src/ui_mainwindow.h" line="757"/>
        <source>Edit Exclusion File</source>
        <translation>अपवर्जन फाइल का संपादन</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="643"/>
        <location filename="../src/ui_mainwindow.h" line="758"/>
        <source>Pictures</source>
        <translation>चित्र</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="650"/>
        <location filename="../src/ui_mainwindow.h" line="759"/>
        <source>Videos</source>
        <translation>वीडियो</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="657"/>
        <location filename="../src/ui_mainwindow.h" line="760"/>
        <source>All of the above</source>
        <translation>ऊपर दिए सभी</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="664"/>
        <location filename="../src/ui_mainwindow.h" line="762"/>
        <source>exclude network configurations</source>
        <translation>अपवर्जित नेटवर्क विन्यास</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="667"/>
        <location filename="../src/ui_mainwindow.h" line="764"/>
        <source>Networks</source>
        <translation>नेटवर्क</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="674"/>
        <location filename="../src/ui_mainwindow.h" line="765"/>
        <source>Downloads</source>
        <translation>डाउनलोड</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="681"/>
        <location filename="../src/ui_mainwindow.h" line="766"/>
        <source>Desktop</source>
        <translation>डेस्कटॉप</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="688"/>
        <location filename="../src/ui_mainwindow.h" line="767"/>
        <source>Documents</source>
        <translation>प्रलेख</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="695"/>
        <location filename="../src/ui_mainwindow.h" line="768"/>
        <source>Flatpaks</source>
        <translation>फ्लैटपैक</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="702"/>
        <location filename="../src/ui_mainwindow.h" line="769"/>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="814"/>
        <location filename="../src/ui_mainwindow.h" line="772"/>
        <source>About this application</source>
        <translation>इस अनुप्रयोग के बारे में</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="817"/>
        <location filename="../src/ui_mainwindow.h" line="774"/>
        <source>About...</source>
        <translation>बारे में...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="823"/>
        <location filename="../src/ui_mainwindow.h" line="776"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="839"/>
        <location filename="../src/ui_mainwindow.h" line="778"/>
        <source>Next</source>
        <translation>अगला</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="864"/>
        <location filename="../src/ui_mainwindow.h" line="783"/>
        <source>Display help </source>
        <translation>सहायता देखें</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="867"/>
        <location filename="../src/ui_mainwindow.h" line="785"/>
        <source>Help</source>
        <translation>सहायता</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="873"/>
        <location filename="../src/ui_mainwindow.h" line="787"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="886"/>
        <location filename="../src/ui_mainwindow.h" line="790"/>
        <source>Quit application</source>
        <translation>अनुप्रयोग बंद करें</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="889"/>
        <location filename="../src/ui_mainwindow.h" line="792"/>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="895"/>
        <location filename="../src/ui_mainwindow.h" line="794"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="949"/>
        <location filename="../src/ui_mainwindow.h" line="797"/>
        <source>Back</source>
        <translation>पीछे</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="144"/>
        <source>Select Release Date</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="188"/>
        <source>fastest, worst compression</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="188"/>
        <source>fast, worse compression</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="189"/>
        <source>slow, better compression</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="189"/>
        <source>best compromise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="190"/>
        <source>slowest, best compression</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="219"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>%1 पर अप्रयुक्त स्पेस जहाँ स्नैपशॉट फोल्डर स्थित है :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="222"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space by removing previous snapshots and saved copies: %1 snapshots are taking up %2 of disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="234"/>
        <location filename="../src/mainwindow.cpp" line="235"/>
        <source>Installing </source>
        <translation>इंस्टॉल जारी</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="320"/>
        <source>Please wait.</source>
        <translation>प्रतीक्षा करें।</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="322"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>प्रतीक्षा करें। प्रयुक्त डिस्क स्पेस गणना जारी...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="356"/>
        <location filename="../src/mainwindow.cpp" line="413"/>
        <source>Error</source>
        <translation>त्रुटि</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="357"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="362"/>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="368"/>
        <source>Snapshot will use the following settings:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="370"/>
        <source>- Snapshot directory:</source>
        <translation>- स्नैपशॉट फोल्डर :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="371"/>
        <source>- Kernel to be used:</source>
        <translation>- प्रयुक्त होने वाला कर्नेल :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="393"/>
        <location filename="../src/mainwindow.cpp" line="402"/>
        <source>NVIDIA Detected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="394"/>
        <source>This computer uses an NVIDIA graphics card. Are you planning to use the resulting ISO on the same computer or another computer with an NVIDIA card?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <source>NVIDIA Selected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="399"/>
        <source>Note: If you use the resulting ISO on a computer without an NVIDIA card, you will likely need to remove &apos;xorg=nvidia&apos; from the boot options.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="403"/>
        <source>Note: If you use the resulting ISO on a computer with an NVIDIA card, you may need to add &apos;xorg=nvidia&apos; to the boot options.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="414"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>वर्तमान कर्नेल हेतु चयनित संपीड़न एल्गोरिथम असमर्थित है, कृपया विन्यास फाइल संपादित कर विभिन्न एल्गोरिथम चुनें।</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="437"/>
        <source>Final chance</source>
        <translation>अंतिम पुष्टिकरण</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="439"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>आपके कार्यरत सिस्टम के आईएसओ सृजन हेतु आवश्यक सभी सूचना अब स्नैपशॉट को उपलब्ध है।</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="440"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>इंस्टॉल हो रखें सिस्टम व कंप्यूटर क्षमता अनुसार प्रक्रिया पूर्ण होने में कुछ समय लग सकता है।</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="442"/>
        <source>OK to start?</source>
        <translation>आरंभ करें?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="446"/>
        <source>Shutdown computer when done.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <source>Output</source>
        <translation>आउटपुट</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="495"/>
        <source>Close</source>
        <translation>बंद करें</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="502"/>
        <source>Edit Boot Menu</source>
        <translation>बूट मेन्यू संपादन</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="503"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>आप द्वारा कार्यरत डायरेक्टरी में सम्मिलित फाइलों के संपादन हेतु प्रोग्राम अभी स्थगित है। बूट मेन्यू संपादन हेतु हाँ या यह चरण निरस्त कर स्नैपशॉट बनाना जारी रखने हेतु नहीं का चयन करें।</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="599"/>
        <source>About %1</source>
        <translation>%1 के बारे में</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="601"/>
        <source>Version: </source>
        <translation>संस्करण :</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="602"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>एमएक्स लिनक्स के कार्यरत सिस्टम से लाइव-सीडी बनाने हेतु प्रोग्राम</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>Copyright (c) MX Linux</source>
        <translation>कॉपीराइट (c) एमएक्स लिनक्स</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="606"/>
        <source>%1 License</source>
        <translation>%1 लाइसेंस</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="620"/>
        <source>%1 Help</source>
        <translation>%1 सहायता</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="625"/>
        <source>Select Snapshot Directory</source>
        <translation>स्नैपशॉट फोल्डर चुनें</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="646"/>
        <source>Confirmation</source>
        <translation>पुष्टिकरण</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="646"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>क्या आप निश्चित ही अनुप्रयोग बंद करना चाहते हैं?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="77"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation>कार्यरत सिस्टम से लाइव-सीडी बनाने हेतु हेतु सहायक साधन</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <source>Use CLI only</source>
        <translation>केवल कमांड लाइन उपयोग करें</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>Number of CPU cores to be used.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="86"/>
        <source>Output directory</source>
        <translation>आउटपुट डायरेक्टरी</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="87"/>
        <source>Output filename</source>
        <translation>आउटपुट फाइल नाम</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="89"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation>डिफ़ॉल्ट कार्यरत कर्नेल के स्थान पर अन्य कर्नेल उपयोग करने हेतु संबंधित नाम दर्ज करें, &apos;uname -r&apos; कमांड से प्राप्त प्रारूप उपयोग करें</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="91"/>
        <source>Or the full path: %1</source>
        <translation>या पूर्ण पथ : %1</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="94"/>
        <source>Compression level options.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="95"/>
        <source>Use quotes: &quot;-Xcompression-level &lt;level&gt;&quot;, or &quot;-Xalgorithm &lt;algorithm&gt;&quot;, or &quot;-Xhc&quot;, see mksquashfs man page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="99"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation>मासिक स्नैपशॉट बनाने के दौरान आईएसओ नाम में &apos;माह&apos; नाम जोड़ें, स्पेस गणना निरस्त करें</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="100"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation>इस विकल्प से अकाउंट पुनः सेट करना व संपीड़न डिफ़ॉल्ट पर सेट होंगे, इन वस्तुओं को प्रभावित करने वाले मापदंड अनदेखे होंगे</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="102"/>
        <source>Optionally specify a suffix to add to the month name (e.g., &apos;1&apos; for &apos;July.1&apos;)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="103"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation>प्रक्रिया परिणामस्वरूप निर्मित आईएसओ फाइल चेकसम की गणना न करें</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="104"/>
        <source>Skip calculating free space to see if the resulting ISO will fit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="105"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation>preempt_rt कर्नेल पर चेकसम गणना समस्या के सुधार हेतु विकल्प</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="106"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>अकाउंट पुनः सेट करना जारी (अन्य को वितरण हेतु)</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="107"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation>प्रक्रिया परिणामस्वरूप निर्मित आईएसओ फाइल चेकसम की गणना करें</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="109"/>
        <source>Throttle the I/O input rate by the given percentage. This can be used to reduce the I/O and CPU consumption of Mksquashfs.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Work directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="114"/>
        <source>Exclude main folders, valid choices: </source>
        <translation>मुख्य फोल्डर अपवर्जित, मान्य विकल्प :</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="116"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation>इच्छित वस्तु के अपवर्जन हेतु विकल्प को प्रत्येक वस्तु हेतु एकल रूप से उपयोग करें</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="119"/>
        <source>Compression format, valid choices: </source>
        <translation>संपीड़न प्रारूप, मान्य विकल्प :</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="121"/>
        <source>Shutdown computer when done.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="170"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>प्रतीत होता है कि आप रुट के रूप में लॉगिन हैं, प्रोग्राम उपयोग करने हेतु लॉगआउट कर सामान्य उपयोक्ता के रूप में लॉगिन करें।</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="188"/>
        <source>version:</source>
        <translation>संस्करण :</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="182"/>
        <source>You must run this program with sudo or pkexec.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/main.cpp" line="165"/>
        <source>MX Snapshot</source>
        <translation>एमएक्स स्नैपशॉट</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="453"/>
        <location filename="../src/settings.cpp" line="461"/>
        <location filename="../src/settings.cpp" line="936"/>
        <location filename="../src/settings.cpp" line="1030"/>
        <location filename="../src/main.cpp" line="172"/>
        <location filename="../src/main.cpp" line="239"/>
        <source>Error</source>
        <translation>त्रुटि</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="460"/>
        <location filename="../src/main.cpp" line="238"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation>वर्तमान कर्नेल द्वारा Squashfs समर्थित नहीं है, प्रक्रिया निरस्त।</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="57"/>
        <source>Failed to initialize configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="80"/>
        <source>Configuration validation failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="85"/>
        <source>Exception during initialization: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="88"/>
        <source>Unknown exception during initialization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="119"/>
        <source>Could not create work directory. </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="143"/>
        <source>Could not create temp directory:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="144"/>
        <source>Please check that the parent directory exists and is writable:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="162"/>
        <source>Compression format &apos;%1&apos; is not supported by the current kernel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="168"/>
        <source>Invalid cores setting: %1. Must be between 1 and %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="174"/>
        <source>Invalid throttle setting: %1. Must be between 0 and 20</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="180"/>
        <source>Snapshot directory cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="188"/>
        <source>Snapshot name cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="194"/>
        <source>Snapshot name contains invalid characters: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="200"/>
        <source>Kernel version cannot be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="205"/>
        <source>Kernel file not found: /boot/vmlinuz-%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="211"/>
        <source>Kernel %1 doesn&apos;t support Squashfs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="235"/>
        <source>Exclusion file does not exist: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="244"/>
        <source>Unbalanced quotes in exclusion list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="269"/>
        <source>Insufficient free space: %1 KiB available, minimum %2 KiB required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="276"/>
        <source>Insufficient free space in work directory: %1 KiB available, minimum %2 KiB required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="291"/>
        <source>Failed to determine number of CPU cores</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="297"/>
        <source>Configuration file does not exist: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="298"/>
        <source>Using default settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="300"/>
        <source>Cannot read configuration file: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="301"/>
        <source>Error: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="311"/>
        <source>Required tool not found: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="320"/>
        <source>Required directory not found: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="339"/>
        <source>Initialization Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="340"/>
        <source>Failed to initialize application settings:

%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="451"/>
        <source>Could not find a usable kernel</source>
        <translation>उपयोग हेतु कर्नेल प्राप्ति विफल</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="452"/>
        <source>Searched for kernel files in /boot/ but none were found or accessible.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="473"/>
        <source>No users found in the system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="476"/>
        <source>Failed to determine system information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="570"/>
        <source>Used space on / (root): </source>
        <translation>/ (root) पर प्रयुक्त स्पेस :</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="573"/>
        <source>estimated</source>
        <translation>अनुमान</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="582"/>
        <source>Used space on /home: </source>
        <translation>/home पर प्रयुक्त स्पेस :</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="638"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>%1 पर अप्रयुक्त स्पेस जहाँ स्नैपशॉट फोल्डर स्थित है :</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="642"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>/ व /home के संपीड़ित डेटा के संचय हेतु अप्रयुक्त स्पेस उपयुक्त होना आवश्यक है

      आवश्यक होने पर, आप पूर्व स्नैपशॉट व संचित प्रतिलिपियों
      को हटाकर अधिक स्पेस उपलब्ध करा सकते हैं :
      स्नैपशॉट द्वारा %2 डिस्क स्पेस प्रयुक्त।
</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="656"/>
        <source>Desktop</source>
        <translation>डेस्कटॉप</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="657"/>
        <source>Documents</source>
        <translation>प्रलेख</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="658"/>
        <source>Downloads</source>
        <translation>डाउनलोड</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="659"/>
        <source>Flatpaks</source>
        <translation>फ्लैटपैक</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="660"/>
        <source>Music</source>
        <translation>संगीत</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="661"/>
        <source>Networks</source>
        <translation>नेटवर्क</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="662"/>
        <source>Pictures</source>
        <translation>चित्र</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="664"/>
        <source>Videos</source>
        <translation>वीडियो</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="813"/>
        <source>Error reading system configuration file: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="818"/>
        <source>Error accessing user configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="934"/>
        <location filename="../src/settings.cpp" line="1028"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <source>License</source>
        <translation>लाइसेंस</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <location filename="../src/about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>बदलाव सूची</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>बंद करें (&amp;C)</translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../src/work.cpp" line="116"/>
        <source>Cleaning...</source>
        <translation>अनावश्यक वस्तुएँ हटाना जारी...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="130"/>
        <location filename="../src/work.cpp" line="320"/>
        <source>Done</source>
        <translation>पूर्ण</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="142"/>
        <source>Interrupted or failed to complete</source>
        <translation>बाधित या पूर्ण होने विफल</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="175"/>
        <location filename="../src/work.cpp" line="278"/>
        <location filename="../src/work.cpp" line="300"/>
        <location filename="../src/work.cpp" line="338"/>
        <location filename="../src/work.cpp" line="476"/>
        <source>Error</source>
        <translation>त्रुटि</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="176"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation>लक्षित डिस्क पर पर्याप्त अप्रयुक्त स्पेस नहीं है, कम-से-कम %1 होना आवश्यक है</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="179"/>
        <source>You have %1 free space on %2</source>
        <translation>%2 पर %1 अप्रयुक्त स्पेस है</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="182"/>
        <source>If you are sure you have enough free space rerun the program with -o/--override-size option</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/work.cpp" line="207"/>
        <source>Copying the new-iso filesystem...</source>
        <translation>नवीन-आईएसओ फाइल सिस्टम कॉपी करना जारी...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="219"/>
        <source>Could not create temp directory. </source>
        <translation>अस्थायी डायरेक्टरी बनाना विफल।</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="275"/>
        <source>Squashing filesystem...</source>
        <translation>फाइल सिस्टम संपीड़न जारी...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="279"/>
        <source>Could not create linuxfs file, please check /var/log/%1.log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/work.cpp" line="297"/>
        <source>Creating CD/DVD image file...</source>
        <translation>सीडी/डीवीडी फाइल बनाना जारी...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="301"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation>आईएसओ फाइल बनाना विफल, कृपया सुनिश्चित करें कि लक्षित विभाजन पर उपयुक्त स्पेस उपलब्ध है।</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="307"/>
        <source>Making hybrid iso</source>
        <translation>समग्र आईएसओ बनाना जारी</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="325"/>
        <source>Success</source>
        <translation>सफल</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="326"/>
        <source>MX Snapshot completed successfully!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/work.cpp" line="327"/>
        <source>Snapshot took %1 to finish.</source>
        <translation>स्नैपशॉट बनाने में %1 समय लगा। </translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="328"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation>एमएक्स स्नैपशॉट उपयोग करने हेतु धन्यवाद, अब एमएक्स लाइव यूएसबी निर्माता उपयोग करें!</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="335"/>
        <source>Installing </source>
        <translation>इंस्टॉल जारी</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="338"/>
        <source>Could not install </source>
        <translation>इंस्टॉल विफल</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="348"/>
        <source>Calculating checksum...</source>
        <translation>चेकसम गणना गणना जारी...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="386"/>
        <source>Building new initrd...</source>
        <translation>नवीन initrd बनाना जारी...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="477"/>
        <source>Could not create working directory. </source>
        <translation>कार्यरत डायरेक्टरी बनाना विफल।</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="615"/>
        <source>Calculating total size of excluded files...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/work.cpp" line="625"/>
        <source>Calculating size of root...</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>